define("ace/ext/statusbar",["require","exports","module","ace/lib/dom","ace/lib/lang"], function(require, exports, module) {
"use strict";
var dom = require("ace/lib/dom");
var lang = require("ace/lib/lang");

var StatusBar = function(editor, parentNode) {
    this.element = dom.createElement("div");
    this.element.className = "ace_status-indicator";
    this.element.style.cssText = "display: inline-block;";    
    this.elementStatusText = dom.createElement("div");
    this.elementStatusText.id = "statusText";
    this.elementStatusText.style.cssText = "position:absolute;";
    this.elementStatusText.textContent = parentNode.textContent;
    parentNode.textContent = "";
    parentNode.appendChild(this.elementStatusText);
    parentNode.appendChild(this.element);

    
    var statusUpdate = lang.delayedCall(function(){
        this.updateStatus(editor);
    }.bind(this)).schedule.bind(null, 100);

    
    editor.on("changeStatus", statusUpdate);
    editor.on("changeSelection", statusUpdate);
    editor.on("keyboardActivity", statusUpdate);
    
	this.updateText = function(text) {
		this.elementStatusText.textContent = text;
	};    
    
};

(function(){
    this.updateStatus = function(editor) {
        var status = [];
        function add(str, separator) {
            str && status.push(str, separator || "|");
        }

        add(editor.keyBinding.getStatusText(editor));
        if (editor.commands.recording)
            add("REC");
        
        var sel = editor.selection;
        var c = sel.lead;
        
        if (!sel.isEmpty()) {
            var r = editor.getSelectionRange();
            var rown = r.end.row - r.start.row + 1;
            var columnn = r.end.column - r.start.column; //+ 1;
            add("(" + (rown) + ":"  +(columnn) + ")", " ");
        }
        var rown = c.row + 1;
        var columnn = c.column; //+ 1;
        add(rown + ":" + columnn, " ");        
        if (sel.rangeCount)
            add("[" + sel.rangeCount + "]", " ");
        status.pop();
        this.element.textContent = status.join("");
    };
}).call(StatusBar.prototype);

exports.StatusBar = StatusBar;

});
                (function() {
                    window.require(["ace/ext/statusbar"], function() {});
                })();
            