function drawDevice(pitch, roll, yaw, maxPitch, maxRoll) {
	var canvas = document.getElementById("canvas");
	var ctx = canvas.getContext("2d");
	var half = canvas.height / 2;
	ctx.translate(half, half);
	var radius = half * 0.70;

	function toRad(grad) {
		return grad * Math.PI / 180;
	}
	function mapAngle(grad) {
		return Math.asin(grad / 90);
	}

	function drawFace(ctx, radius) {
		function drawTicks(offset) {
			var ticksOnSideCount = 10;
			for (var i = 0; i <= ticksOnSideCount; i++) {
				var radiuss = radius * 1.25
				var angle = offset + i * Math.PI / (3 * ticksOnSideCount);
				var sineAngle = Math.sin(angle);
				var cosAngle = -Math.cos(angle);
				var iPointX = 0;
				var iPointY = 0;
				var oPointX = 0;
				var oPointY = 0;
				if (i % (ticksOnSideCount / 2) == 0) {
					ctx.lineWidth = 3;
					iPointX = sineAngle * (radiuss - 0.23 * radiuss);
					iPointY = cosAngle * (radiuss - 0.23 * radiuss);
					oPointX = sineAngle * (radiuss - 0.42 * radiuss);
					oPointY = cosAngle * (radiuss - 0.42 * radiuss);
				} else {
					// Small Ticks
					ctx.lineWidth = 2;
					iPointX = sineAngle * (radiuss - 0.23 * radiuss);
					iPointY = cosAngle * (radiuss - 0.23 * radiuss);
					oPointX = sineAngle * (radiuss - 0.32 * radiuss);
					oPointY = cosAngle * (radiuss - 0.32 * radiuss);
				}
				ctx.beginPath();
				ctx.strokeStyle = "#DCDCDC";

				ctx.moveTo(iPointX, iPointY);
				ctx.lineTo(oPointX, oPointY);
				ctx.stroke();
			}
		}

		// Рамка прибора
		ctx.beginPath();
		ctx.arc(0, 0, radius, 0, 2 * Math.PI);
		ctx.lineWidth = radius * 0.2;

		var grad = ctx.createRadialGradient(0, 0, radius * 0.93, 0, 0,
				radius * 1.1);
		grad.addColorStop(0, 'transparent');
		grad.addColorStop(0.7, '#999');
		grad.addColorStop(1.0, 'black');
		ctx.strokeStyle = grad;
		ctx.stroke();

		// Гвоздь в середине
		ctx.beginPath();
		ctx.arc(0, 0, radius * 0.03, 0, 2 * Math.PI);
		ctx.fillStyle = '#999';
		ctx.fill();
		ctx.stroke();

		// Черточки
		drawTicks(Math.PI / 3);
		drawTicks(4 * Math.PI / 3);
		
		// Север-Юг
		ctx.font = "bold 20px Army";
		ctx.fillStyle = "#DCDCDC";
		ctx.fillText("N",-6,-0.8*radius+7); 
		ctx.fillText("S",-6,0.8*radius+7); 
		
	}
	function drawPitch(ctx, radius, pitch) {

		// Верх
		ctx.beginPath();
		ctx.arc(0, 0, radius, -2 * Math.PI + mapAngle(pitch), Math.PI
				- mapAngle(pitch), true);
		ctx.fillStyle = "#7496fc";
		ctx.fill();
		ctx.lineCap = "butt";
		ctx.lineWidth = 1;
		ctx.strokeStyle = "black";
		ctx.stroke();

		// Низ
		ctx.beginPath();
		ctx.arc(0, 0, radius, -Math.PI - mapAngle(pitch), -2 * Math.PI
				+ mapAngle(pitch), true);
		ctx.closePath();
		ctx.fillStyle = '#542110';
		ctx.fill();
		ctx.lineCap = "butt";
		ctx.lineWidth = 1;
		ctx.strokeStyle = "black";
		ctx.stroke();

		// Оповещение об опасном угле
		if (Math.abs(pitch) > maxPitch) {
			ctx.beginPath();
			ctx.arc(0, 0, radius - 1, 0, 2 * Math.PI, true);
			ctx.closePath();
			ctx.lineWidth = 8;
			ctx.strokeStyle = "red";
			ctx.stroke();
		}
	}
	function drawRoll(ctx, radius, rollGrad) {

		function drawWings(ctx, pos, length, width, handColor) {
			var x0 = -25 * Math.cos(pos);
			var y0 = 25 * Math.sin(pos);
			var x1 = -length * Math.cos(pos);
			var y1 = length * Math.sin(pos);

			// Первое крыло
			ctx.beginPath();
			ctx.strokeStyle = handColor;

			ctx.lineWidth = width;
			ctx.moveTo(x0, y0);
			ctx.lineCap = "round";
			ctx.lineTo(x1, y1);
			ctx.stroke();

			// Второе крыло
			ctx.beginPath();

			ctx.moveTo(-x0, -y0);
			ctx.lineCap = "round";
			ctx.lineTo(-x1, -y1);
			ctx.stroke();
		}
		var clr = Math.abs(rollGrad) > maxRoll ? "red" : "yellow";
		var rollRad = -toRad(rollGrad);
		drawWings(ctx, rollRad, radius * 0.75, radius * 0.06, clr);

		// Полукруг в центре
		ctx.beginPath();
		ctx.arc(0, 0, radius * 0.1, Math.PI - rollRad, -rollRad, true);
		ctx.strokeStyle = clr;
		ctx.stroke();
	}
	function drawYaw(ctx, radius, yawGrad) {
		function triCircle(ctx, radius, angle) {
			var triLength1 = 15;
			var triLength2 = 8;
			var PI = Math.PI;
			var x0 = radius * Math.cos(angle);
			var y0 = radius * Math.sin(angle);

			var tricx = 0 + (radius + triLength1) * Math.cos(angle);
			var tricy = 0 + (radius + triLength1) * Math.sin(angle);
			var x1 = tricx + (triLength2) * Math.cos(angle - PI / 2);
			var y1 = tricy + (triLength2) * Math.sin(angle - PI / 2);
			var x2 = tricx + (triLength2) * Math.cos(angle + PI / 2);
			var y2 = tricy + (triLength2) * Math.sin(angle + PI / 2);
			ctx.beginPath();
			ctx.moveTo(x0, y0);
			ctx.lineTo(x1, y1);
			ctx.lineTo(x2, y2);
			ctx.closePath();
			ctx.lineWidth = 2;
			ctx.fillStyle = 'red';
			ctx.fill();
			ctx.strokeStyle = "#999";
			ctx.stroke();
		}
		var up = 3 / 2 * Math.PI
		var yawRad = up + toRad(yawGrad);
		triCircle(ctx, radius * 1.2, yawRad);
	}

	ctx.clearRect(-canvas.width, -canvas.height, 2 * canvas.width,
			2 * canvas.height);
	drawPitch(ctx, radius, pitch);
	drawFace(ctx, radius);
	drawRoll(ctx, radius, roll);
	drawYaw(ctx, radius, yaw);
	ctx.translate(-half, -half);
}